==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-clock/clock_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="50"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;basato su locale&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation>Impostazioni dell&apos;orologio di LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Impostazioni orologio</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Ora</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Mostra i secondi</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>&amp;Stile 12 ore</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Usa UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>Formato &amp;data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>&amp;Non mostrare la data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Prima la &amp;data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Prima l&apos;&amp;ora</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Mostra la data su una &amp;seconda riga</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Primo giorno della settimana</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Orientazione</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Ruota automaticamente se il pannello è verticale</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Carattere</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Carattere</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation>Mostra la &amp;data</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation>&amp;Formato della data</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation>Cara&amp;ttere</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation>Mostra la data in una &amp;nuova riga</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation>&amp;Utilizza i caratteri del tema</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation>Carattere dell&apos;ora</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation>Carattere della data</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation>Chiarissimo</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Chiaro</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation>Nerissimo</translation>
    </message>
    <message>
        <source>Black</source>
        <translation>Nero</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation>Neretto</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Corsivo</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="284"/>
        <source>Input custom date format</source>
        <translation>Formato personalizzato</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="284"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>Sequenze interpretate del formato della data sono:

d	il giorno come numero senza uno zero iniziale (da 1 a 31)
dd	il giorno come numero con uno zero iniziale (da 01 a 31)
ddd	il nome del giorno localizzato abbreviato (ad es. da &apos;Lun&apos; a &apos;Dom&apos;).
dddd	il nome del giorno localizzato esteso (ad es. da &apos;Lunedì&apos; a &apos;Domenica&apos;).
M	il mese come numero senza uno zero iniziale (1-12)
MM	il mese come numero con uno zero iniziale (01-12)
MMM	il nome del mese localizzato abbreviato (ad es. da &apos;Gen&apos; a &apos;Dic&apos;).
MMMM	il nome del mese localizzato esteso (ad es. da &apos;Gennaio&apos; a &apos;Dicembre&apos;).
yy	l&apos;anno come numero a due cifre (00-99)
yyyy	l&apos;anno come numero a quattro cifre

Tutti gli altri caratteri saranno trattati come testo.
Qualsiasi sequenza di caratteri racchiusa tra singoli apici (&apos;)
sarà trattata come testo e non sarà utilizzata come un&apos;espressione.


Formato personalizzato della data:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-clock/clock_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;basato su locale&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Impostazioni dell&apos;orologio di LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Impostazioni orologio</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Ora</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Mostra i secondi</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>&amp;Stile 12 ore</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Usa UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>Formato &amp;data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>&amp;Non mostrare la data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Prima la &amp;data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Prima l&apos;&amp;ora</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Mostra la data su una &amp;seconda riga</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Primo giorno della settimana</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Orientazione</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Ruota automaticamente se il pannello è verticale</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">&amp;Carattere</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Carattere</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Mostra la &amp;data</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">&amp;Formato della data</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">Cara&amp;ttere</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Mostra la data in una &amp;nuova riga</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Utilizza i caratteri del tema</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Carattere dell&apos;ora</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Carattere della data</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Chiarissimo</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Chiaro</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Nerissimo</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Nero</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Grassetto</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Neretto</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Corsivo</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Formato personalizzato</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>Sequenze interpretate del formato della data sono:

d	il giorno come numero senza uno zero iniziale (da 1 a 31)
dd	il giorno come numero con uno zero iniziale (da 01 a 31)
ddd	il nome del giorno localizzato abbreviato (ad es. da &apos;Lun&apos; a &apos;Dom&apos;).
dddd	il nome del giorno localizzato esteso (ad es. da &apos;Lunedì&apos; a &apos;Domenica&apos;).
M	il mese come numero senza uno zero iniziale (1-12)
MM	il mese come numero con uno zero iniziale (01-12)
MMM	il nome del mese localizzato abbreviato (ad es. da &apos;Gen&apos; a &apos;Dic&apos;).
MMMM	il nome del mese localizzato esteso (ad es. da &apos;Gennaio&apos; a &apos;Dicembre&apos;).
yy	l&apos;anno come numero a due cifre (00-99)
yyyy	l&apos;anno come numero a quattro cifre

Tutti gli altri caratteri saranno trattati come testo.
Qualsiasi sequenza di caratteri racchiusa tra singoli apici (&apos;)
sarà trattata come testo e non sarà utilizzata come un&apos;espressione.


Formato personalizzato della data:</translation>
    </message>
</context>
</TS>
